@@ -5,9 +5,9 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::ETHER::AUTHORITY = 'cpan:ETHER';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.031';
+  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.032';
 }
-# git description: v0.030-7-g39d7b62
+# git description: v0.031-8-gc720ab3
 
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 
@@ -78,6 +78,8 @@ sub configure
 {
     my $self = shift;
 
+    my %extra_develop_requires;
+
     $self->add_plugins(
         # VersionProvider
         [ 'Git::NextVersion'    => { version_regexp => '^v([\d._]+)(-TRIAL)?$' } ],
@@ -101,7 +103,6 @@ sub configure
 
         [ 'Test::Compile'       => {
             ':version' => '2.036',
-            fail_on_warning => 'author',
             bail_out_on_fail => 1,
             xt_mode => 1,
             script_finder => [qw(:ExecFiles @Author::ETHER/Examples)],
@@ -136,7 +137,8 @@ sub configure
         [ 'NextRelease'         => { ':version' => '4.300018', time_zone => 'UTC', format => '%-8V  %{yyyy-MM-dd HH:mm:ss\'Z\'}d (%U)' } ],
 
         # MetaData
-        $self->server eq 'github' ? ( [ 'GithubMeta' ] ) : (),
+        $self->server eq 'github'
+            ? ( 'GithubMeta', do { $extra_develop_requires{'Dist::Zilla::Plugin::GithubMeta'} = 0; () }) : (),
         [ 'AutoMetaResources'   => { 'bugtracker.rt' => 1,
               $self->server eq 'gitmo' ? ( 'repository.gitmo' => 1 )
             : $self->server eq 'p5sagit' ? ( 'repository.p5sagit' => 1 )
@@ -158,8 +160,9 @@ sub configure
                 'Dist::Zilla' => Dist::Zilla->VERSION,
                 blessed($self) => $self->_requested_version,
 
-                # this is mostly pointless as by the time this runs, we're
-                # already trying to load the installer plugin
+                # this is useless for "dzil authordeps", as by the time this
+                # runs, we're already trying to load the installer plugin --
+                # but it is useful for people doing "cpanm --with-develop"
                 ( map {
                     Dist::Zilla::Util->expand_config_package_name($_) =>
                         ($installer_args{$_} // {})->{':version'} // 0
@@ -179,6 +182,7 @@ sub configure
         'InstallGuide',
 
         # After Build
+        'CheckSelfDependency',
         [ 'CopyFilesFromBuild'  => { copy => [ qw(LICENSE CONTRIBUTING) ] } ],
         [ 'Run::AfterBuild' => { run => q{if [ `dirname %d` != .build ]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi} } ],
 
@@ -198,7 +202,10 @@ sub configure
         # After Release
         [ 'Git::Commit'         => { allow_dirty => [ qw(Changes README.md LICENSE CONTRIBUTING) ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
-        $self->server eq 'github' ? ( [ 'GitHub::Update' => { metacpan => 1 } ] ) : (),
+        $self->server eq 'github' ? (
+            [ 'GitHub::Update' => { metacpan => 1 } ],
+            do { $extra_develop_requires{'Dist::Zilla::Plugin::GitHub::Update'} = 0; () },
+        ) : (),
         'Git::Push',
         [ 'InstallRelease'      => { install_command => 'cpanm .' } ],
 
@@ -206,6 +213,13 @@ sub configure
         'ConfirmRelease',
     );
 
+    $self->add_plugins(
+        [ 'Prereqs' => via_options => {
+            '-phase' => 'develop', '-relationship' => 'requires',
+            %extra_develop_requires
+          } ]
+    ) if keys %extra_develop_requires;
+
     # check for a bin/ that should probably be renamed to script/
     warn 'bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?'
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
@@ -228,7 +242,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.031
+version 0.032
 
 =head1 SYNOPSIS
 
@@ -379,6 +393,7 @@ following F<dist.ini> (following the preamble):
 
 
     ;;; After Build
+    [CheckSelfDependency]
     [CopyFilesFromBuild]
     copy = LICENSE
     copy = CONTRIBUTING
